RabbitMqPool

Struct RabbitMqPool 

pub struct RabbitMqPool { /* private fields */ }
RabbitMQ connection pool which manages connection based on the amount of channels used per connection

Keeps a configured minimum of connections alive but creates them lazily when enough channels are requested

Implementations

Source

impl RabbitMqPool

pub fn from_config( url: &str, min_connections: u32, max_channels_per_connection: u32, ) -> Arc<Self>

Creates a new RabbitMqPool from given parameters

Spawns a connection reaper task on the tokio runtime

pub async fn make_connection(&self) -> Result<Connection, Error>

Create a connection with the pools given params

This just creates a connection and does not add it to its pool. Connections will automatically be created when creating channels.

pub async fn create_channel(&self) -> Result<RabbitMqChannel, Error>

Create a rabbitmq channel using one of the connections of the pool

If there are no connections available or all connections are at the channel cap a new connection will be created

pub async fn close( &self, reply_code: u16, reply_message: &str, ) -> Result<(), Error>

Close all connections managed by the pool with the given code and message